---------------------------------------------------------------------
-- Modifies door actions so that they have a HUDpriority set. This way
-- we can force our door actions to appear after them in the UI.
--
-- If HUDpriority is not set on an action then it is assumed to be math.huge
-- It's impossible to set a value larger than math.huge so this makes it
-- impossible to ensure that doorSlam or agentDoorBreak will appear after
-- the door open/close action.
-- This fixes that by changing the default priorty to 1000.
local agent_actions = include("hud/agent_actions")

local old_generatePotentialActions = agent_actions.generatePotentialActions
agent_actions.generatePotentialActions = function(hud, actions, unit, cellx, celly)
	old_generatePotentialActions(hud, actions, unit, cellx, celly)
	for key, action in pairs(actions) do
		if action.priority == nil then
			action.priority = 1000
		end
	end
end

return nil
