----------------------------------------
-- This ability allows an agent to choose
-- to throw any carryable item. Grenades
-- can also be chosen, allowing them to be
-- thrown without activating them.
--
-- Intended use of this ability is to
-- throw items to other agents or on the
-- ground as a distraction to guards.
--
-- selectItemToss and selectItemDeploy
-- work together to add two buttons to
-- the ui that can be used to toggle
-- between 'toss' mode and 'deploy' mode
-- In 'deploy' mode, throwing an item will
-- cause it to activate. This only applies
-- to grenades.
-- In 'toss' mode, throwing an item will
-- only teleport it to the chosen square,
-- where it can later be picked up again.
-- Default mode is 'deploy'.

local cdefs = include("client_defs")
local abilityutil = include("sim/abilities/abilityutil")

local throwShared = include(EXTRA_AGENT_ABILITIES_SCRIPT_PATH .."/itemThrow/throwShared")

--local PATH_ICON_ACTIVE = "gui/icons/icon-action_item_throw.png"
--local PATH_ICON_INACTIVE = "gui/icons/icon-action_item_throw_darkened.png"

local selectItemToss =
{
	ICON_COLOR_ACTIVE = nil,
	ICON_COLOR_INACTIVE = nil,

	name = STRINGS.EXTRA_AGENT_ABILITIES.TOOLTIPS.THROW_TOSS,
	getName = function(self, sim, unit, userUnit)
		if unit.getTraits and unit:getTraits().eaa_isThrowing == true then
			return STRINGS.EXTRA_AGENT_ABILITIES.TOOLTIPS.THROW_TOSSING
		end
		return self.name
	end,

	createToolTip = function(self, sim, unit)
		return abilityutil.formatToolTip(STRINGS.EXTRA_AGENT_ABILITIES.TOOLTIPS.THROW_TOSS,  STRINGS.EXTRA_AGENT_ABILITIES.TOOLTIPS.THROW_TOSS_DESC, 1)
	end,

	profile_icon = "gui/icons/icon-action_item_throw.png",
	usesMP = true, -- <- The actual truth of this depends on what ITEM_THROW_MP_COST was set to.
	iconColor = nil,
	iconColorHover = cdefs.COLOR_FREE_HOVER,

	canUseAbility = function(self, sim, abilityOwner, abilityUser)
		if abilityUser:getMP() < throwShared.modInfo.ITEM_THROW_MP_COST then
			return false, string.format(STRINGS.UI.REASON.REQUIRES_AP, throwShared.modInfo.ITEM_THROW_MP_COST)
		end

		return true
	end,

	onSpawnAbility = function(self, sim, unit)
		self.abilityOwner = unit
		sim:addTrigger("EAA_TRG_ITEM_THROW_CANCEL", self)
		sim:addTrigger("EAA_TRG_ITEM_TOSS", self)
		sim:addTrigger("EAA_TRG_ITEM_DEPLOY", self)
	end,

	onDespawnAbility = function(self, sim, unit)
		sim:removeTrigger("EAA_TRG_ITEM_THROW_CANCEL", self)
		sim:removeTrigger("EAA_TRG_ITEM_TOSS", self)
		sim:removeTrigger("EAA_TRG_ITEM_DEPLOY", self)
		self.abilityOwner = nil
	end,

	onTrigger = function(self, sim, evType, evData)
		if evType == "EAA_TRG_ITEM_THROW_CANCEL" then
			self.abilityOwner:getTraits().eaa_isThrowing = nil
			self.iconColor = self.ICON_COLOR_INACTIVE
		elseif evType == "EAA_TRG_ITEM_TOSS" then
			self.abilityOwner:getTraits().eaa_isThrowing = true
			self.iconColor = self.ICON_COLOR_ACTIVE
		elseif evType == "EAA_TRG_ITEM_DEPLOY" then
			self.abilityOwner:getTraits().eaa_isThrowing = nil
			self.iconColor = self.ICON_COLOR_INACTIVE
		end
	end,

	executeAbility = function(self, sim, unit, userUnit)
		sim:triggerEvent("EAA_TRG_ITEM_TOSS", {itemUnit = unit})
		sim:dispatchEvent("EAA_EV_ITEM_THROW", {itemUnit = unit, itemUser = userUnit})
		-- see onTrigger() for effects
	end,
}

return selectItemToss
